Data Transformations
********************

Transformations
==================
.. autoclass:: ai4water.preprocessing.transformations.Transformation
   :members:
   :undoc-members:
   :show-inheritance:

   .. automethod:: __init__

.. autoclass:: ai4water.preprocessing.transformations.Transformations
   :members:
   :undoc-members:
   :show-inheritance:

   .. automethod:: __init__
        
.. autoclass:: ai4water.preprocessing.transformations.ScalerWithConfig
   :members:
   :undoc-members:
   :show-inheritance:

   .. automethod:: __init__

.. autoclass:: ai4water.preprocessing.transformations.PowerTransformer
   :members:
   :undoc-members:
   :show-inheritance:

   .. automethod:: __init__

.. autoclass:: ai4water.preprocessing.transformations.FunctionTransformer
   :members:
   :undoc-members:
   :show-inheritance:

   .. automethod:: __init__
